@@ -30,7 +30,6 @@ or other dealings in this Software without prior written authorization
 of the copyright holder.
 
 ************************************************************/
-/* $XdotOrg: xserver/xorg/Xext/xevie.c,v 1.11 2005/10/06 17:55:54 alanc Exp $ */
 
 #define NEED_REPLIES
 #define NEED_EVENTS
@@ -53,17 +52,19 @@ of the copyright holder.
 #include "inputstr.h"
 #include "windowstr.h"
 #include "cursorstr.h"
-#include <X11/extensions/XKBsrv.h>
+#include <xkbsrv.h>
 
 #include "../os/osdep.h"
 
 #define NoSuchEvent 0x80000000
 
+#ifdef XKB
 extern Bool noXkbExtension;
+#endif
 extern int    xeviegrabState;
 
-static int		ProcDispatch (), SProcDispatch ();
-static void		ResetProc ();
+static int		ProcDispatch (register ClientPtr client), SProcDispatch (register ClientPtr client);
+static void		ResetProc (ExtensionEntry *extEntry);
 
 static unsigned char	ReqCode = 0;
 static int		ErrorBase;
@@ -104,7 +105,7 @@ typedef struct {
 } xevieKeycQueueRec, *xevieKeycQueuePtr;
 
 #define KEYC_QUEUE_SIZE	    100
-xevieKeycQueueRec keycq[KEYC_QUEUE_SIZE] = {0, NULL};
+static xevieKeycQueueRec keycq[KEYC_QUEUE_SIZE] = {{0, NULL}};
 static int keycqHead = 0, keycqTail = 0;
 
 static int              ProcDispatch (ClientPtr), SProcDispatch (ClientPtr);
@@ -129,7 +130,7 @@ static void XeviePointerProcessInputProc(xEvent *xE, DeviceIntPtr dev,
 static void XevieKbdProcessInputProc(xEvent *xE, DeviceIntPtr dev, int count);
 
 void
-XevieExtensionInit ()
+XevieExtensionInit (void)
 {
     ExtensionEntry* extEntry;
 
@@ -158,18 +159,14 @@ XevieExtensionInit ()
 
 /*ARGSUSED*/
 static 
-void ResetProc (extEntry)
-    ExtensionEntry* extEntry;
+void ResetProc (ExtensionEntry *extEntry)
 {
 }
 
 static 
-int ProcQueryVersion (client)
-    register ClientPtr client;
+int ProcQueryVersion (register ClientPtr client)
 {
-    REQUEST (xXevieQueryVersionReq);
     xXevieQueryVersionReply rep;
-    register int n;
 
     REQUEST_SIZE_MATCH (xXevieQueryVersionReq);
     rep.type = X_Reply;
@@ -182,12 +179,9 @@ int ProcQueryVersion (client)
 }
 
 static
-int ProcStart (client)
-    register ClientPtr client;
+int ProcStart (register ClientPtr client)
 {
-    REQUEST (xXevieStartReq);
     xXevieStartReply rep;
-    register int n;
 
     REQUEST_SIZE_MATCH (xXevieStartReq);
     rep.pad1 = 0;
@@ -208,12 +202,14 @@ int ProcStart (client)
            return BadAlloc;
     } else
         return BadAccess;
+#ifdef XKB
     if (!noXkbExtension) {
 	if (!XevieStart()) {
             DeleteCallback(&ClientStateCallback,XevieClientStateCallback,NULL);
             return BadAlloc;
         }
     }
+#endif
     
     xevieModifiersOn = FALSE;
 
@@ -224,8 +220,7 @@ int ProcStart (client)
 }
 
 static
-int ProcEnd (client)
-    register ClientPtr client;
+int ProcEnd (register ClientPtr client)
 {
     xXevieEndReply rep;
 
@@ -244,13 +239,11 @@ int ProcEnd (client)
 }
 
 static
-int ProcSend (client)
-    register ClientPtr client;
+int ProcSend (register ClientPtr client)
 {
     REQUEST (xXevieSendReq);
     xXevieSendReply rep;
     xEvent *xE;
-    OsCommPtr oc;
     static unsigned char lastDetail = 0, lastType = 0;
 
     if (client->index != xevieClientIndex)
@@ -265,19 +258,23 @@ int ProcSend (client)
 	case KeyPress:
         case KeyRelease:
 	  xevieKBEventSent = 1;
-          if(noXkbExtension)
-            CoreProcessKeyboardEvent (xE, xeviekb, 1);
-	  else 
+#ifdef XKB
+          if(!noXkbExtension)
 	    doSendEvent(xE, inputInfo.keyboard);
+	  else 
+#endif
+            CoreProcessKeyboardEvent (xE, xeviekb, 1);
 	  break;
 	case ButtonPress:
 	case ButtonRelease:
 	case MotionNotify:
 	  xevieEventSent = 1;
-	  if(noXkbExtension)
-	    CoreProcessPointerEvent(xE, xeviemouse, 1); 
-	  else
+#ifdef XKB
+	  if(!noXkbExtension)
 	    doSendEvent(xE, inputInfo.pointer);
+	  else
+#endif
+	    CoreProcessPointerEvent(xE, xeviemouse, 1); 
 	  break; 
 	default:
 	  break;
@@ -288,8 +285,7 @@ int ProcSend (client)
 }
 
 static
-int ProcSelectInput (client)
-    register ClientPtr client;
+int ProcSelectInput (register ClientPtr client)
 {
     REQUEST (xXevieSelectInputReq);
     xXevieSelectInputReply rep;
@@ -305,8 +301,7 @@ int ProcSelectInput (client)
 }
 
 static 
-int ProcDispatch (client)
-    register ClientPtr	client;
+int ProcDispatch (register ClientPtr client)
 {
     REQUEST (xReq);
     switch (stuff->data)
@@ -327,8 +322,7 @@ int ProcDispatch (client)
 }
 
 static 
-int SProcQueryVersion (client)
-    register ClientPtr	client;
+int SProcQueryVersion (register ClientPtr client)
 {
     register int n;
 
@@ -338,8 +332,7 @@ int SProcQueryVersion (client)
 }
 
 static 
-int SProcStart (client)
-    ClientPtr client;
+int SProcStart (ClientPtr client)
 {
     register int n;
 
@@ -351,12 +344,9 @@ int SProcStart (client)
 }
 
 static 
-int SProcEnd (client)
-    ClientPtr client;
+int SProcEnd (ClientPtr client)
 {
     register int n;
-    int count;
-    xColorItem* pItem;
 
     REQUEST (xXevieEndReq);
     swaps (&stuff->length, n);
@@ -366,11 +356,9 @@ int SProcEnd (client)
 }
 
 static
-int SProcSend (client)
-    ClientPtr client;
+int SProcSend (ClientPtr client)
 {
     register int n;
-    int count;
 
     REQUEST (xXevieSendReq);
     swaps (&stuff->length, n);
@@ -380,11 +368,9 @@ int SProcSend (client)
 }
 
 static
-int SProcSelectInput (client)
-    ClientPtr client;
+int SProcSelectInput (ClientPtr client)
 {
     register int n;
-    int count;
 
     REQUEST (xXevieSelectInputReq);
     swaps (&stuff->length, n);
@@ -395,8 +381,7 @@ int SProcSelectInput (client)
 
 
 static 
-int SProcDispatch (client)
-    register ClientPtr	client;
+int SProcDispatch (register ClientPtr client)
 {
     REQUEST(xReq);
     switch (stuff->data)
@@ -486,6 +471,7 @@ XevieKbdProcessInputProc(xEvent *xE, DeviceIntPtr dev, int count)
         xE->u.keyButtonPointer.state = keyc->state | inputInfo.pointer->button->state;
         /* fix bug: sequence lost in Xlib */
         xE->u.u.sequenceNumber = clients[xevieClientIndex]->sequence;
+#ifdef XKB
 	/* fix for bug5092586 */
 	if(!noXkbExtension) {
           switch(xE->u.u.type) {
@@ -493,6 +479,7 @@ XevieKbdProcessInputProc(xEvent *xE, DeviceIntPtr dev, int count)
 	    case KeyRelease: *kptr &= ~bit; break;
 	  }
 	}
+#endif
 	keycq[keycqHead].time = xE->u.keyButtonPointer.time;
 	memcpy(keycq[keycqHead].keyc, keyc, sizeof(KeyClassRec) - sizeof(KeyClassPtr));
 	memcpy(keycq[keycqHead].keyc->xkbInfo, keyc->xkbInfo, sizeof(XkbSrvInfoRec));
@@ -547,6 +534,7 @@ XevieEnd(int clientIndex)
 {
     if (!clientIndex || clientIndex == xevieClientIndex) {
 
+#ifdef XKB
        if(!noXkbExtension) {
 
 	   XevieRemove(inputInfo.keyboard,NULL);
@@ -562,6 +550,7 @@ XevieEnd(int clientIndex)
            inputInfo.pointer->public.realInputProc = CoreProcessPointerEvent;
            XkbSetExtension(inputInfo.pointer,ProcessPointerEvent);
        }
+#endif
 
        xevieFlag = 0;
        xevieClientIndex = 0;
