@@ -1,3 +1,4 @@
 #define MFBIMAGEGLYPHBLT xf1bppImageGlyphBltBlack
 #define OPEQ &=~
-#include "../../../../mfb/mfbimggblt.c"
+#include "mfbmap.h"
+#include "../../../mfb/mfbimggblt.c"
